@@ -72,6 +72,7 @@ from awscli.customizations.sessendemail import register_ses_send_email
 from awscli.customizations.streamingoutputarg import add_streaming_output_arg
 from awscli.customizations.toplevelbool import register_bool_params
 from awscli.customizations.waiters import register_add_waiters
+from awscli.customizations.opsworkscm import register_alias_opsworks_cm
 
 
 def awscli_initialize(event_handlers):
@@ -146,3 +147,4 @@ def awscli_initialize(event_handlers):
     register_gamelift_commands(event_handlers)
     register_ec2_page_size_injector(event_handlers)
     cloudformation_init(event_handlers)
+    register_alias_opsworks_cm(event_handlers)
